## Dataset Attribution
This inventory was created by Sandra L. Bem. The use of the lexicons from the
paper is believed to be *fair use* for the reasons stated in the `FAIR_USE.md`
file.

- Original Source: _Evidence That Gendered Wording in Job Advertisements Exists
and Sustains Gender Inequality_ [[Gaucher et al 2011](https://ideas.wharton.upenn.edu/wp-content/uploads/2018/07/Gaucher-Friesen-Kay-2011.pdf)].
- Changes Made: The original words often use * to indicate any suffix, we have
completed these with a reasonable candidates. We have removed words that were
not adjectives.

